@@ -15,11 +15,11 @@ Passwd::Keyring::PWSafe3 - Password storage based on Password Safe encrypted fil
 
 =head1 VERSION
 
-Version 0.2005
+Version 1.0000
 
 =cut
 
-our $VERSION = '0.2006';
+our $VERSION = '1.0000';
 
 our $APP_NAME = "Passwd::Keyring";
 our $FOLDER_NAME = "Perl-Passwd-Keyring";
@@ -27,25 +27,15 @@ our $FOLDER_NAME = "Perl-Passwd-Keyring";
 =head1 SYNOPSIS
 
 Password Safe implementation of L<Passwd::Keyring>. Passwords are
-stored in the Password Safe encrypted file (see
-L<http://passwordsafe.sourceforge.net> for details,
-Windows and Linux versions are available).
-
-This module does not require Password Safe to be installed, and can be
-used as generic "store many passwords in file encrypted with single
-master password" storage. Password Safe GUI, if installed, may help
-the user to review, modify, or delete saved passwords.
-
-Note: actual handling of Password Safe format is based on L<Crypt::PWSafe3>
-module. Passwd::Keyring::PWSafe3 just wraps it into the interface compatible
-with other Passwd::Keyring backends.
+stored in the L<Password Safe|http://passwordsafe.sourceforge.net>
+encrypted file.
 
     use Passwd::Keyring::PWSafe3;
 
     my $keyring = Passwd::Keyring::PWSafe3->new(
          app=>"blahblah scraper",
          group=>"Johnny web scrapers",
-         file=>"/home/joe/secrets.pwsafe3",        # HOME / passwd-keyring.pwsafe3 by default
+         file=>"/home/joe/secrets.pwsafe3",        # ~/passwd-keyring.pwsafe3 by default
          master_password=>"very secret password",  # Or callback. See below
     );
 
@@ -64,7 +54,29 @@ with other Passwd::Keyring backends.
         $keyring->clear_password($username, "blahblah.com");
     }
 
-Note: see L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments
+=head1 DESCRIPTION
+
+This module does not require Password Safe to be installed, and can be
+used as generic "store many passwords in file encrypted with single
+master password" storage. Password Safe GUI, if installed, may help
+the user to review, modify, or delete saved passwords.
+
+=over 4
+
+Official GUIs can be freely downloaded from L<the official
+site|http://passwordsafe.sourceforge.net> - both Windows and (beta)
+Linux versions are available. Apart from them there exist
+various L<compatible tools|http://passwordsafe.sourceforge.net/relatedprojects.shtml>,
+for example <Pasaffe for Gnome|https://launchpad.net/pasaffe>  or
+<PwSafe for Mac|http://passwordsafe.sourceforge.net/relatedprojects.shtml>.
+
+=back
+
+Actual handling of Password Safe format is based on L<Crypt::PWSafe3>
+module. Passwd::Keyring::PWSafe3 just wraps it into the interface
+compatible with other Passwd::Keyring backends.
+
+See L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments
 on keyring methods (this document is installed with
 C<Passwd::Keyring::Auto> package).
 
@@ -121,7 +133,7 @@ absolute path is required, relative paths are very error prone.
 
 =item master_password 
 
-Password required to unlock the file. Can be Specified as string, or
+Password required to unlock the file. Can be given as string, or
 as callback returning a string (usually some way of interactively
 asking user for the password).  The callback gets two parameters: app
 and file.
@@ -159,7 +171,7 @@ sub new {
     $self->{app} = $args{app} || 'Passwd::Keyring::PWSafe3';
     $self->{group} = $args{group} || 'Passwd::Keyring';
     $self->{lazy_save} = $args{lazy_save};
-    my $file = $args{file} || File::Spec->catfile($ENV{HOME}, "passwd-keyring.pwsafe3");
+    my $file = $args{file} || File::Spec->catfile(File::HomeDir->users_data, "passwd-keyring.pwsafe3");
 
     unless(File::Spec->file_name_is_absolute($file)) {
         croak("Absolute path to .pwsafe3 file is required, but relative path '$file' given");
@@ -321,8 +333,8 @@ Marcin Kasperski
 
 =head1 BUGS
 
-Please report any bugs or feature requests to 
-issue tracker at L<https://bitbucket.org/Mekk/perl-keyring-pwsafe3>.
+Please report any bugs or feature requests to
+issue tracker at L<https://helixteamhub.cloud/mekk/projects/perl/issues>.
 
 =head1 SUPPORT
 
@@ -336,7 +348,7 @@ L<http://search.cpan.org/~mekk/Passwd-Keyring-PWSafe3/>
 
 Source code is tracked at:
 
-L<https://bitbucket.org/Mekk/perl-keyring-pwsafe3>
+L<https://helixteamhub.cloud/mekk/projects/perl/repositories/keyring-pwsafe3>
 
 =head1 LICENSE AND COPYRIGHT
 
